obelisk.sync.consumer
=====================

.. automodule:: obelisk.sync.consumer

   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      Consumer
   